==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/OperationHistoryFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OperationHistoryFluentImpl<A extends OperationHistoryFluent<A>> extends BaseFluent<A> implements OperationHistoryFluent<A>{
  public OperationHistoryFluentImpl() {
  }
  public OperationHistoryFluentImpl(OperationHistory instance) {
    this.withDeprovision(instance.getDeprovision()); 
    this.withInspect(instance.getInspect()); 
    this.withProvision(instance.getProvision()); 
    this.withRegister(instance.getRegister()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private OperationMetricBuilder deprovision;
  private OperationMetricBuilder inspect;
  private OperationMetricBuilder provision;
  private OperationMetricBuilder register;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildDeprovision instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getDeprovision() {
    return this.deprovision!=null ?this.deprovision.build():null;
  }
  public OperationMetric buildDeprovision() {
    return this.deprovision!=null ?this.deprovision.build():null;
  }
  public A withDeprovision(OperationMetric deprovision) {
    _visitables.get("deprovision").remove(this.deprovision);
    if (deprovision!=null){ this.deprovision= new OperationMetricBuilder(deprovision); _visitables.get("deprovision").add(this.deprovision);} else { this.deprovision = null; _visitables.get("deprovision").remove(this.deprovision); } return (A) this;
  }
  public Boolean hasDeprovision() {
    return this.deprovision != null;
  }
  public A withNewDeprovision(String end,String start) {
    return (A)withDeprovision(new OperationMetric(end, start));
  }
  public OperationHistoryFluent.DeprovisionNested<A> withNewDeprovision() {
    return new OperationHistoryFluentImpl.DeprovisionNestedImpl();
  }
  public OperationHistoryFluent.DeprovisionNested<A> withNewDeprovisionLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.DeprovisionNestedImpl(item);
  }
  public OperationHistoryFluent.DeprovisionNested<A> editDeprovision() {
    return withNewDeprovisionLike(getDeprovision());
  }
  public OperationHistoryFluent.DeprovisionNested<A> editOrNewDeprovision() {
    return withNewDeprovisionLike(getDeprovision() != null ? getDeprovision(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluent.DeprovisionNested<A> editOrNewDeprovisionLike(OperationMetric item) {
    return withNewDeprovisionLike(getDeprovision() != null ? getDeprovision(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildInspect instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getInspect() {
    return this.inspect!=null ?this.inspect.build():null;
  }
  public OperationMetric buildInspect() {
    return this.inspect!=null ?this.inspect.build():null;
  }
  public A withInspect(OperationMetric inspect) {
    _visitables.get("inspect").remove(this.inspect);
    if (inspect!=null){ this.inspect= new OperationMetricBuilder(inspect); _visitables.get("inspect").add(this.inspect);} else { this.inspect = null; _visitables.get("inspect").remove(this.inspect); } return (A) this;
  }
  public Boolean hasInspect() {
    return this.inspect != null;
  }
  public A withNewInspect(String end,String start) {
    return (A)withInspect(new OperationMetric(end, start));
  }
  public OperationHistoryFluent.InspectNested<A> withNewInspect() {
    return new OperationHistoryFluentImpl.InspectNestedImpl();
  }
  public OperationHistoryFluent.InspectNested<A> withNewInspectLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.InspectNestedImpl(item);
  }
  public OperationHistoryFluent.InspectNested<A> editInspect() {
    return withNewInspectLike(getInspect());
  }
  public OperationHistoryFluent.InspectNested<A> editOrNewInspect() {
    return withNewInspectLike(getInspect() != null ? getInspect(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluent.InspectNested<A> editOrNewInspectLike(OperationMetric item) {
    return withNewInspectLike(getInspect() != null ? getInspect(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProvision instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getProvision() {
    return this.provision!=null ?this.provision.build():null;
  }
  public OperationMetric buildProvision() {
    return this.provision!=null ?this.provision.build():null;
  }
  public A withProvision(OperationMetric provision) {
    _visitables.get("provision").remove(this.provision);
    if (provision!=null){ this.provision= new OperationMetricBuilder(provision); _visitables.get("provision").add(this.provision);} else { this.provision = null; _visitables.get("provision").remove(this.provision); } return (A) this;
  }
  public Boolean hasProvision() {
    return this.provision != null;
  }
  public A withNewProvision(String end,String start) {
    return (A)withProvision(new OperationMetric(end, start));
  }
  public OperationHistoryFluent.ProvisionNested<A> withNewProvision() {
    return new OperationHistoryFluentImpl.ProvisionNestedImpl();
  }
  public OperationHistoryFluent.ProvisionNested<A> withNewProvisionLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.ProvisionNestedImpl(item);
  }
  public OperationHistoryFluent.ProvisionNested<A> editProvision() {
    return withNewProvisionLike(getProvision());
  }
  public OperationHistoryFluent.ProvisionNested<A> editOrNewProvision() {
    return withNewProvisionLike(getProvision() != null ? getProvision(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluent.ProvisionNested<A> editOrNewProvisionLike(OperationMetric item) {
    return withNewProvisionLike(getProvision() != null ? getProvision(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildRegister instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getRegister() {
    return this.register!=null ?this.register.build():null;
  }
  public OperationMetric buildRegister() {
    return this.register!=null ?this.register.build():null;
  }
  public A withRegister(OperationMetric register) {
    _visitables.get("register").remove(this.register);
    if (register!=null){ this.register= new OperationMetricBuilder(register); _visitables.get("register").add(this.register);} else { this.register = null; _visitables.get("register").remove(this.register); } return (A) this;
  }
  public Boolean hasRegister() {
    return this.register != null;
  }
  public A withNewRegister(String end,String start) {
    return (A)withRegister(new OperationMetric(end, start));
  }
  public OperationHistoryFluent.RegisterNested<A> withNewRegister() {
    return new OperationHistoryFluentImpl.RegisterNestedImpl();
  }
  public OperationHistoryFluent.RegisterNested<A> withNewRegisterLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.RegisterNestedImpl(item);
  }
  public OperationHistoryFluent.RegisterNested<A> editRegister() {
    return withNewRegisterLike(getRegister());
  }
  public OperationHistoryFluent.RegisterNested<A> editOrNewRegister() {
    return withNewRegisterLike(getRegister() != null ? getRegister(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluent.RegisterNested<A> editOrNewRegisterLike(OperationMetric item) {
    return withNewRegisterLike(getRegister() != null ? getRegister(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperationHistoryFluentImpl that = (OperationHistoryFluentImpl) o;
    if (deprovision != null ? !deprovision.equals(that.deprovision) :that.deprovision != null) return false;
    if (inspect != null ? !inspect.equals(that.inspect) :that.inspect != null) return false;
    if (provision != null ? !provision.equals(that.provision) :that.provision != null) return false;
    if (register != null ? !register.equals(that.register) :that.register != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deprovision,  inspect,  provision,  register,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deprovision != null) { sb.append("deprovision:"); sb.append(deprovision + ","); }
    if (inspect != null) { sb.append("inspect:"); sb.append(inspect + ","); }
    if (provision != null) { sb.append("provision:"); sb.append(provision + ","); }
    if (register != null) { sb.append("register:"); sb.append(register + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class DeprovisionNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluent.DeprovisionNested<N>> implements OperationHistoryFluent.DeprovisionNested<N>,Nested<N>{
    DeprovisionNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    DeprovisionNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withDeprovision(builder.build());
    }
    public N endDeprovision() {
      return and();
    }
    
  }
  class InspectNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluent.InspectNested<N>> implements OperationHistoryFluent.InspectNested<N>,Nested<N>{
    InspectNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    InspectNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withInspect(builder.build());
    }
    public N endInspect() {
      return and();
    }
    
  }
  class ProvisionNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluent.ProvisionNested<N>> implements OperationHistoryFluent.ProvisionNested<N>,Nested<N>{
    ProvisionNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    ProvisionNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withProvision(builder.build());
    }
    public N endProvision() {
      return and();
    }
    
  }
  class RegisterNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluent.RegisterNested<N>> implements OperationHistoryFluent.RegisterNested<N>,Nested<N>{
    RegisterNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    RegisterNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withRegister(builder.build());
    }
    public N endRegister() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/OperationHistoryFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OperationHistoryFluentImpl<A extends OperationHistoryFluent<A>> extends BaseFluent<A> implements OperationHistoryFluent<A>{
  public OperationHistoryFluentImpl() {
  }
  public OperationHistoryFluentImpl(OperationHistory instance) {
    if (instance != null) {
      this.withDeprovision(instance.getDeprovision());
      this.withInspect(instance.getInspect());
      this.withProvision(instance.getProvision());
      this.withRegister(instance.getRegister());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private OperationMetricBuilder deprovision;
  private OperationMetricBuilder inspect;
  private OperationMetricBuilder provision;
  private OperationMetricBuilder register;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildDeprovision instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getDeprovision() {
    return this.deprovision!=null ?this.deprovision.build():null;
  }
  public OperationMetric buildDeprovision() {
    return this.deprovision!=null ?this.deprovision.build():null;
  }
  public A withDeprovision(OperationMetric deprovision) {
    _visitables.get("deprovision").remove(this.deprovision);
    if (deprovision!=null){ this.deprovision= new OperationMetricBuilder(deprovision); _visitables.get("deprovision").add(this.deprovision);} else { this.deprovision = null; _visitables.get("deprovision").remove(this.deprovision); } return (A) this;
  }
  public Boolean hasDeprovision() {
    return this.deprovision != null;
  }
  public A withNewDeprovision(String end,String start) {
    return (A)withDeprovision(new OperationMetric(end, start));
  }
  public OperationHistoryFluentImpl.DeprovisionNested<A> withNewDeprovision() {
    return new OperationHistoryFluentImpl.DeprovisionNestedImpl();
  }
  public OperationHistoryFluentImpl.DeprovisionNested<A> withNewDeprovisionLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.DeprovisionNestedImpl(item);
  }
  public OperationHistoryFluentImpl.DeprovisionNested<A> editDeprovision() {
    return withNewDeprovisionLike(getDeprovision());
  }
  public OperationHistoryFluentImpl.DeprovisionNested<A> editOrNewDeprovision() {
    return withNewDeprovisionLike(getDeprovision() != null ? getDeprovision(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluentImpl.DeprovisionNested<A> editOrNewDeprovisionLike(OperationMetric item) {
    return withNewDeprovisionLike(getDeprovision() != null ? getDeprovision(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildInspect instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getInspect() {
    return this.inspect!=null ?this.inspect.build():null;
  }
  public OperationMetric buildInspect() {
    return this.inspect!=null ?this.inspect.build():null;
  }
  public A withInspect(OperationMetric inspect) {
    _visitables.get("inspect").remove(this.inspect);
    if (inspect!=null){ this.inspect= new OperationMetricBuilder(inspect); _visitables.get("inspect").add(this.inspect);} else { this.inspect = null; _visitables.get("inspect").remove(this.inspect); } return (A) this;
  }
  public Boolean hasInspect() {
    return this.inspect != null;
  }
  public A withNewInspect(String end,String start) {
    return (A)withInspect(new OperationMetric(end, start));
  }
  public OperationHistoryFluentImpl.InspectNested<A> withNewInspect() {
    return new OperationHistoryFluentImpl.InspectNestedImpl();
  }
  public OperationHistoryFluentImpl.InspectNested<A> withNewInspectLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.InspectNestedImpl(item);
  }
  public OperationHistoryFluentImpl.InspectNested<A> editInspect() {
    return withNewInspectLike(getInspect());
  }
  public OperationHistoryFluentImpl.InspectNested<A> editOrNewInspect() {
    return withNewInspectLike(getInspect() != null ? getInspect(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluentImpl.InspectNested<A> editOrNewInspectLike(OperationMetric item) {
    return withNewInspectLike(getInspect() != null ? getInspect(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProvision instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getProvision() {
    return this.provision!=null ?this.provision.build():null;
  }
  public OperationMetric buildProvision() {
    return this.provision!=null ?this.provision.build():null;
  }
  public A withProvision(OperationMetric provision) {
    _visitables.get("provision").remove(this.provision);
    if (provision!=null){ this.provision= new OperationMetricBuilder(provision); _visitables.get("provision").add(this.provision);} else { this.provision = null; _visitables.get("provision").remove(this.provision); } return (A) this;
  }
  public Boolean hasProvision() {
    return this.provision != null;
  }
  public A withNewProvision(String end,String start) {
    return (A)withProvision(new OperationMetric(end, start));
  }
  public OperationHistoryFluentImpl.ProvisionNested<A> withNewProvision() {
    return new OperationHistoryFluentImpl.ProvisionNestedImpl();
  }
  public OperationHistoryFluentImpl.ProvisionNested<A> withNewProvisionLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.ProvisionNestedImpl(item);
  }
  public OperationHistoryFluentImpl.ProvisionNested<A> editProvision() {
    return withNewProvisionLike(getProvision());
  }
  public OperationHistoryFluentImpl.ProvisionNested<A> editOrNewProvision() {
    return withNewProvisionLike(getProvision() != null ? getProvision(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluentImpl.ProvisionNested<A> editOrNewProvisionLike(OperationMetric item) {
    return withNewProvisionLike(getProvision() != null ? getProvision(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildRegister instead.
   * @return The buildable object.
   */
  @Deprecated
  public OperationMetric getRegister() {
    return this.register!=null ?this.register.build():null;
  }
  public OperationMetric buildRegister() {
    return this.register!=null ?this.register.build():null;
  }
  public A withRegister(OperationMetric register) {
    _visitables.get("register").remove(this.register);
    if (register!=null){ this.register= new OperationMetricBuilder(register); _visitables.get("register").add(this.register);} else { this.register = null; _visitables.get("register").remove(this.register); } return (A) this;
  }
  public Boolean hasRegister() {
    return this.register != null;
  }
  public A withNewRegister(String end,String start) {
    return (A)withRegister(new OperationMetric(end, start));
  }
  public OperationHistoryFluentImpl.RegisterNested<A> withNewRegister() {
    return new OperationHistoryFluentImpl.RegisterNestedImpl();
  }
  public OperationHistoryFluentImpl.RegisterNested<A> withNewRegisterLike(OperationMetric item) {
    return new OperationHistoryFluentImpl.RegisterNestedImpl(item);
  }
  public OperationHistoryFluentImpl.RegisterNested<A> editRegister() {
    return withNewRegisterLike(getRegister());
  }
  public OperationHistoryFluentImpl.RegisterNested<A> editOrNewRegister() {
    return withNewRegisterLike(getRegister() != null ? getRegister(): new OperationMetricBuilder().build());
  }
  public OperationHistoryFluentImpl.RegisterNested<A> editOrNewRegisterLike(OperationMetric item) {
    return withNewRegisterLike(getRegister() != null ? getRegister(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperationHistoryFluentImpl that = (OperationHistoryFluentImpl) o;
    if (!java.util.Objects.equals(deprovision, that.deprovision)) return false;

    if (!java.util.Objects.equals(inspect, that.inspect)) return false;

    if (!java.util.Objects.equals(provision, that.provision)) return false;

    if (!java.util.Objects.equals(register, that.register)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(deprovision,  inspect,  provision,  register,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deprovision != null) { sb.append("deprovision:"); sb.append(deprovision + ","); }
    if (inspect != null) { sb.append("inspect:"); sb.append(inspect + ","); }
    if (provision != null) { sb.append("provision:"); sb.append(provision + ","); }
    if (register != null) { sb.append("register:"); sb.append(register + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class DeprovisionNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluentImpl.DeprovisionNested<N>> implements OperationHistoryFluentImpl.DeprovisionNested<N>,Nested<N>{
    DeprovisionNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    DeprovisionNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withDeprovision(builder.build());
    }
    public N endDeprovision() {
      return and();
    }
    
  }
  class InspectNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluentImpl.InspectNested<N>> implements OperationHistoryFluentImpl.InspectNested<N>,Nested<N>{
    InspectNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    InspectNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withInspect(builder.build());
    }
    public N endInspect() {
      return and();
    }
    
  }
  class ProvisionNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluentImpl.ProvisionNested<N>> implements OperationHistoryFluentImpl.ProvisionNested<N>,Nested<N>{
    ProvisionNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    ProvisionNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withProvision(builder.build());
    }
    public N endProvision() {
      return and();
    }
    
  }
  class RegisterNestedImpl<N> extends OperationMetricFluentImpl<OperationHistoryFluentImpl.RegisterNested<N>> implements OperationHistoryFluentImpl.RegisterNested<N>,Nested<N>{
    RegisterNestedImpl(OperationMetric item) {
      this.builder = new OperationMetricBuilder(this, item);
    }
    RegisterNestedImpl() {
      this.builder = new OperationMetricBuilder(this);
    }
    OperationMetricBuilder builder;
    public N and() {
      return (N) OperationHistoryFluentImpl.this.withRegister(builder.build());
    }
    public N endRegister() {
      return and();
    }
    
  }
  
}
